# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2

class ButtonDefinition(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ToolDefinitionBase
):  # Class
    def __init__(self) -> None: ...

class CategoryHandlerDefinition:  # Class
    def __init__(self) -> None: ...

    Category: str
    HandlerType: str

class ComboBoxDefinition(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ToolDefinitionBase
):  # Class
    def __init__(self) -> None: ...

    DropDownStyle: System.Windows.Forms.ComboBoxStyle

class ContextMenuDefinition(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.MenuDefinition
):  # Class
    def __init__(self) -> None: ...

    Pane: str

class IComboBox(object):  # Interface
    Count: int  # readonly
    DroppedDown: bool  # readonly
    Id: str  # readonly
    def __getitem__(self, index: int) -> Any: ...
    SelectedItem: Any

    def Clear(self) -> None: ...
    def Add(self, item: Any) -> None: ...

class IDropDownHandler(object):  # Interface
    def DropDownOpening(
        self,
        tool: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IDropDownTool,
        objState: Any,
    ) -> None: ...

class IDropDownTool(object):  # Interface
    Count: int  # readonly
    def __getitem__(
        self, index: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool: ...
    def __getitem__(
        self, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool: ...
    def Add(self, id: str) -> None: ...
    def RegisterDropDownOpening(
        self,
        handler: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IDropDownHandler,
        register: bool,
    ) -> None: ...
    def Clear(self) -> None: ...
    def IndexOf(self, id: str) -> int: ...
    def Remove(self, id: str) -> None: ...
    def Insert(self, id: str, index: int) -> None: ...
    def InsertSeparator(self, index: int) -> None: ...
    def RemoveAt(self, index: int) -> None: ...

class ITextBox(object):  # Interface
    Text: str

class ITool(object):  # Interface
    Checked: bool
    Enabled: bool
    Id: str  # readonly
    IsComboBox: bool  # readonly
    IsDropDownTool: bool  # readonly
    IsTextBox: bool  # readonly

class IToolComboBoxHandler(object):  # Interface
    def SelectedIndexChanged(
        self,
        comboBox: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IComboBox,
        uiState: Any,
    ) -> None: ...
    def DropDown(
        self,
        comboBox: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IComboBox,
        uiState: Any,
    ) -> None: ...
    def DropDownClosed(
        self,
        comboBox: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IComboBox,
        uiState: Any,
    ) -> None: ...

class IToolHandler(object):  # Interface
    def Execute(
        self,
        tool: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool,
        uiState: Any,
    ) -> None: ...
    def SetState(
        self,
        tool: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool,
        uiState: Any,
    ) -> None: ...

class IToolManager(object):  # Interface
    def ContainsCategoryHandler(self, category: str) -> bool: ...
    def RegisterCategoryHandler(
        self,
        category: str,
        handler: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolHandler,
    ) -> None: ...
    def AddToolbar(self, paneId: str, toolbarId: str, text: str) -> None: ...
    def RegisterTool(
        self, id: str, category: str, caption: str, tooltipText: str
    ) -> None: ...
    def RemoveTool(self, id: str) -> None: ...
    def ContainsTool(self, id: str) -> bool: ...
    def RevokeTool(self, id: str) -> None: ...
    def InvokeMouseAction(
        self,
        pane: str,
        button: str,
        mact: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.MouseAction,
        state: str,
    ) -> None: ...
    def RemoveToolbar(self, paneId: str, toolbarId: str) -> None: ...
    def ContainsToolbar(self, paneId: str, toolbarId: str) -> bool: ...
    def GetTools(
        self, id: str
    ) -> List[Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool]: ...

class IToolTextBoxHandler(object):  # Interface
    def TextChanged(
        self,
        textBox: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITextBox,
        uiState: Any,
    ) -> None: ...
    def Leave(
        self,
        textBox: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITextBox,
        uiState: Any,
    ) -> None: ...
    def Enter(
        self,
        textBox: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITextBox,
        uiState: Any,
    ) -> None: ...
    def KeyPress(
        self,
        textBox: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITextBox,
        e: System.Windows.Forms.KeyPressEventArgs,
        uiState: Any,
    ) -> None: ...

class LabelDefinition(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ToolDefinitionBase
):  # Class
    def __init__(self) -> None: ...

class MenuBarDefinition(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ToolbarDefinition
):  # Class
    def __init__(self) -> None: ...

class MenuDefinition(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ToolDefinitionBase
):  # Class
    def __init__(self) -> None: ...

    ShortcutKeys: System.Windows.Forms.Keys

class MouseAction(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Click: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.MouseAction = (
        ...
    )  # static # readonly
    DoubleClick: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.MouseAction
    ) = ...  # static # readonly

class MouseActionKey:  # Class
    def __init__(self) -> None: ...

    Button: str
    MouseAction: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.MouseAction
    Pane: str
    State: str

    def GetHashCode(self) -> int: ...
    def Equals(self, obj: Any) -> bool: ...

class MouseActionMap(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.MouseActionKey
):  # Class
    def __init__(self) -> None: ...

    Action: str

class SeparatorDefinition(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ToolDefinitionBase
):  # Class
    def __init__(self) -> None: ...

class TextBoxDefinition(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ToolDefinitionBase
):  # Class
    def __init__(self) -> None: ...

class ToolDefinitionBase:  # Class
    Alignment: System.Windows.Forms.ToolStripItemAlignment
    Caption: str
    Category: str
    DisplayStyle: System.Windows.Forms.ToolStripItemDisplayStyle
    Id: str
    Image: str
    Tools: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ToolDefinitionBase
    ]
    Tooltip: str
    Visible: bool

class ToolDefinitions:  # Class
    def __init__(self) -> None: ...

    CategoryHandlers: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.CategoryHandlerDefinition
    ]
    ContextMenus: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ContextMenuDefinition
    ]
    Toolbars: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ToolbarDefinition
    ]

class ToolManager(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolManager,
):  # Class
    def __init__(self) -> None: ...

    UIState: Any

    def RegisterCategoryHandler(
        self,
        key: str,
        handler: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolHandler,
    ) -> None: ...
    @overload
    def SetToolState(
        self, tools: System.Windows.Forms.ToolStripItemCollection
    ) -> None: ...
    @overload
    def SetToolState(self, item: System.Windows.Forms.ToolStripItem) -> None: ...
    def InitializeTools(
        self,
        resMgr: System.Resources.ResourceManager,
        panes: Dict[str, System.Windows.Forms.Control],
        definitionsStream: System.IO.Stream,
    ) -> None: ...
    def RegisterTool(
        self, id: str, category: str, caption: str, tooltip: str
    ) -> None: ...
    def RevokeTool(self, id: str) -> None: ...
    def FindItemByShortcut(
        self, key: System.Windows.Forms.Keys
    ) -> System.Windows.Forms.ToolStripMenuItem: ...
    def InvokeMouseAction(
        self,
        pane: str,
        button: str,
        mact: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.MouseAction,
        state: str,
    ) -> None: ...
    def UpdateToolState(self, control: System.Windows.Forms.Control) -> None: ...
    def GetContextMenu(self, id: str) -> System.Windows.Forms.ContextMenuStrip: ...
    def Dispose(self) -> None: ...
    def GetTools(
        self, id: str
    ) -> List[Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool]: ...

class ToolbarDefinition:  # Class
    def __init__(self) -> None: ...

    DockStyle: System.Windows.Forms.DockStyle
    GripStyle: System.Windows.Forms.ToolStripGripStyle
    LayoutStyle: System.Windows.Forms.ToolStripLayoutStyle
    Name: str
    Pane: str
    RenderMode: System.Windows.Forms.ToolStripRenderMode
    Tools: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ToolDefinitionBase
    ]
    Visible: bool



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import (
    Commands,
    Data,
    Models,
    NewMethod,
    Print,
    ScriptIF,
    Tools,
    ViewModels,
    Views,
)
from .Models import IDynamicCalibrationSetupModel

# Stubs for namespace: Agilent.MassHunter.Quantitative.DynamicCalibrationSetup

class App(
    System.Windows.Application,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IHaveResources,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...
    @staticmethod
    def Main() -> None: ...

class DynamicCalibrationSetupException(
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
    System.Exception,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(self, message: str, innerException: System.Exception) -> None: ...

class MainWindow(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.IWindowService,
    Infragistics.Windows.Ribbon.IRibbonWindow,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Animation.IAnimatable,
    System.ComponentModel.ISupportInitialize,
    Infragistics.Windows.Ribbon.XamRibbonWindow,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.Windows.Markup.IAddChild,
    System.Windows.Markup.IComponentConnector,
    System.Windows.Markup.IHaveResources,
):  # Class
    def __init__(self, model: IDynamicCalibrationSetupModel) -> None: ...
    def InitializeComponent(self) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.Configuration

class ApplicationSettings(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.ConfigurationElementSectionBase
):  # Class
    def __init__(self) -> None: ...

    DumpLogOnNormalExit: bool  # readonly
    ErrorReportingEmailAddress: str  # readonly
    ErrorReportingEnabled: bool  # readonly
    Instance: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.Configuration.ApplicationSettings
    )  # static # readonly
    PDFCultures: List[str]  # readonly
    PDFPageSizes: List[str]  # readonly

class ColumnWidthElement(System.Configuration.ConfigurationElement):  # Class
    def __init__(self) -> None: ...

    Name: str
    Width: int

class ColumnWidthElementCollection(
    Iterable[Any], System.Configuration.ConfigurationElementCollection, Sequence[Any]
):  # Class
    def __init__(self) -> None: ...
    def GetWidth(self, name: str, defaultValue: int) -> int: ...
    def SetWidth(self, name: str, value_: int) -> None: ...

class Config:  # Class
    Instance: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.Configuration.Config
    )  # static # readonly

class UISettings(System.Configuration.ConfigurationSection):  # Class
    def __init__(self) -> None: ...

    CompopundGraphicsRangeColumnWidths: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.Configuration.ColumnWidthElementCollection
    )  # readonly
    Instance: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.Configuration.UISettings
    )  # static # readonly
    TemplatesColumnWidths: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.Configuration.ColumnWidthElementCollection
    )  # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import QuantChromSpecControl, QuantitationDataSet

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ChromSpecData

class CachedPeak:  # Class
    def __init__(self) -> None: ...

    Area: float  # readonly
    Base1End: Optional[float]
    Base1Start: Optional[float]
    Base2End: Optional[float]
    Base2Start: Optional[float]
    BaselineEndX: float  # readonly
    BaselineEndY: float  # readonly
    BaselineOffset: Optional[float]
    BaselineStandardDeviation: Optional[float]
    BaselineStartX: float  # readonly
    BaselineStartY: float  # readonly
    CalculatedConcentration: Optional[float]
    Center: float  # readonly
    CenterY: float  # readonly
    CompoundGroup: str
    CompoundName: str
    ConcentrationUnits: str
    ExpectedRetentionTime: Optional[float]  # readonly
    FinalConcentration: Optional[float]
    Height: float  # readonly
    IsPrimary: bool  # readonly
    ManualIntegrated: bool  # readonly
    PeakStatus: Agilent.MassSpectrometry.DataAnalysis.PeakStatus  # readonly
    QValueComputed: Optional[int]
    SignalToNoise: Optional[float]

    @overload
    def Initialize(
        self,
        fxData: Agilent.MassSpectrometry.DataAnalysis.IFXData,
        peak: Agilent.MassSpectrometry.DataAnalysis.IChromPeak,
        expectedRetentionTime: Optional[float],
        primary: bool,
        manualIntegrated: bool,
    ) -> bool: ...
    @overload
    def Initialize(
        self, peakRow: QuantitationDataSet.PeakRow, centerY: float
    ) -> bool: ...
    @overload
    def Initialize(
        self,
        peakRow: QuantitationDataSet.PeakQualifierRow,
        centerY: float,
        primary: bool,
    ) -> bool: ...
    def InitializeOriginal(
        self, sx: float, sy: float, ex: float, ey: float
    ) -> bool: ...

class CompoundMathChromData(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ChromSpecData.SeriesDataBase
):  # Class
    ...

class FXDataSeries(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ChromSpecData.SeriesDataBase
):  # Class
    @staticmethod
    def GetYFromX(
        data: Agilent.MassSpectrometry.DataAnalysis.IFXData, x: float
    ) -> float: ...

class PatternRefSpecData(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ChromSpecData.SeriesDataBase
):  # Class
    ...

class RefSpecData(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ChromSpecData.SeriesDataBase
):  # Class
    ...

class SeriesDataBase:  # Class
    ...

class SpecData(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ChromSpecData.FXDataSeries
):  # Class
    @staticmethod
    def GetFitToPeakMZRange(
        compoundRow: QuantitationDataSet.TargetCompoundRow,
        patternLibraryPath: str,
        control: QuantChromSpecControl,
        minMZ: Optional[float],
        maxMZ: Optional[float],
    ) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
T = TypeVar("T")
from .AppCommand import AppCommandBase, SetGraphicsPropertiesBase

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.Utils

class ComboBoxItem:  # Class
    def __init__(self, value_: Any, displayText: str) -> None: ...

    DisplayText: str  # readonly
    Value: Any  # readonly

class CommandParameterArray(
    Generic[T], Agilent.MassSpectrometry.CommandModel.Model.ICodeDomParameter
):  # Class
    def __init__(self, parameters: Iterable[T]) -> None: ...

class CommandParameterBase:  # Class
    ...

class CompoundGraphicsKey(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.Utils.CommandParameterBase
):  # Class
    def __init__(self, reportID: int, compoundGraphicsID: int) -> None: ...

    CompoundGraphicsID: int  # readonly
    ReportID: int  # readonly

    def GetHashCode(self) -> int: ...
    def Equals(self, obj: Any) -> bool: ...

class CompoundGraphicsRangeColumnValueParameter(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.Utils.CommandParameterBase
):  # Class
    def __init__(
        self, reportID: int, compoundGraphicsID: int, name: str, value_: Any
    ) -> None: ...

    CompoundGraphicsID: int  # readonly
    Name: str  # readonly
    ReportID: int  # readonly
    Value: Any  # readonly

class FormattingColumnValueParameter(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.Utils.CommandParameterBase
):  # Class
    def __init__(
        self, reportID: int, formattingID: int, name: str, value_: Any
    ) -> None: ...

    FormattingID: int  # readonly
    Name: str  # readonly
    ReportID: int  # readonly
    Value: Any  # readonly

class FormattingKey(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.Utils.CommandParameterBase
):  # Class
    def __init__(self, reportID: int, formattingID: int) -> None: ...

    FormattingID: int  # readonly
    ReportID: int  # readonly

    def GetHashCode(self) -> int: ...
    def Equals(self, obj: Any) -> bool: ...

class IImportCompounds(object):  # Interface
    Count: int  # readonly

    def GetProperty(self, index: int, propertyName: str) -> Any: ...

class KeyValue(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.Utils.CommandParameterBase
):  # Class
    def __init__(self, key: str, value_: Any) -> None: ...

    Key: str  # readonly
    Value: Any  # readonly

    def GetHashCode(self) -> int: ...
    @overload
    def Equals(
        self,
        kv: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.Utils.KeyValue,
    ) -> bool: ...
    @overload
    def Equals(self, obj: Any) -> bool: ...

class PrePostProcessColumnValueParameter(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.Utils.CommandParameterBase
):  # Class
    def __init__(
        self, reportID: int, prePostProcessID: int, name: str, value_: Any
    ) -> None: ...

    Name: str  # readonly
    PrePostProcessID: int  # readonly
    ReportID: int  # readonly
    Value: Any  # readonly

class PrePostProcessKey(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.Utils.CommandParameterBase
):  # Class
    def __init__(self, reportID: int, prePostProcessID: int) -> None: ...

    PrePostProcessID: int  # readonly
    ReportID: int  # readonly

class ReportColumnValueParameter(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.Utils.CommandParameterBase
):  # Class
    def __init__(self, reportID: int, name: str, value_: Any) -> None: ...

    Name: str  # readonly
    ReportID: int  # readonly
    Value: Any  # readonly

class Utilities:  # Class
    @overload
    @staticmethod
    def SetColor(
        cmd: SetGraphicsPropertiesBase,
        reportID: int,
        comboBox: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.ColorComboBox,
        row: System.Data.DataRow,
        name: str,
    ) -> None: ...
    @overload
    @staticmethod
    def SetColor(
        cmd: SetGraphicsPropertiesBase,
        reportID: int,
        color: Optional[System.Drawing.Color],
        row: System.Data.DataRow,
        name: str,
    ) -> None: ...
    @staticmethod
    def SetPrimitiveValue(
        cmd: SetGraphicsPropertiesBase,
        reportID: int,
        value_: T,
        row: System.Data.DataRow,
        name: str,
    ) -> None: ...
    @overload
    @staticmethod
    def ConvertColors(
        row: System.Data.DataRow, column: System.Data.DataColumn
    ) -> List[System.Drawing.Color]: ...
    @overload
    @staticmethod
    def ConvertColors(
        row: System.Data.DataRow, name: str
    ) -> List[System.Drawing.Color]: ...
    @staticmethod
    def SetEnumArrayValue(
        cmd: SetGraphicsPropertiesBase,
        reportID: int,
        values: List[T],
        row: System.Data.DataRow,
        name: str,
    ) -> None: ...
    @overload
    @staticmethod
    def ConvertEnum(
        row: System.Data.DataRow, column: System.Data.DataColumn
    ) -> System.Nullable[T]: ...
    @overload
    @staticmethod
    def ConvertEnum(row: System.Data.DataRow, name: str) -> System.Nullable[T]: ...
    @overload
    @staticmethod
    def ConvertEnums(
        row: System.Data.DataRow, column: System.Data.DataColumn
    ) -> List[T]: ...
    @overload
    @staticmethod
    def ConvertEnums(row: System.Data.DataRow, name: str) -> List[T]: ...
    @staticmethod
    def GetMeasurement(
        tb: System.Windows.Forms.TextBox, value_: Optional[float]
    ) -> bool: ...
    @staticmethod
    def ExecuteCommand(
        parent: System.Windows.Forms.Control, cmd: AppCommandBase
    ) -> bool: ...
    @staticmethod
    def BuildColorArrayString(values: List[System.Drawing.Color]) -> str: ...
    @overload
    @staticmethod
    def ConvertColor(
        row: System.Data.DataRow, column: System.Data.DataColumn
    ) -> Optional[System.Drawing.Color]: ...
    @overload
    @staticmethod
    def ConvertColor(
        row: System.Data.DataRow, name: str
    ) -> Optional[System.Drawing.Color]: ...
    @overload
    @staticmethod
    def ConvertColor(color: str) -> Optional[System.Drawing.Color]: ...
    @staticmethod
    def SetColors(
        cmd: SetGraphicsPropertiesBase,
        reportID: int,
        colors: List[System.Drawing.Color],
        row: System.Data.DataRow,
        name: str,
    ) -> None: ...
    @overload
    @staticmethod
    def SetMeasurement(
        tb: System.Windows.Forms.TextBox, row: System.Data.DataRow, name: str
    ) -> None: ...
    @overload
    @staticmethod
    def SetMeasurement(
        cmd: SetGraphicsPropertiesBase,
        reportID: int,
        tb: System.Windows.Forms.TextBox,
        row: System.Data.DataRow,
        name: str,
    ) -> bool: ...
    @staticmethod
    def BuildEnumArrayString(values: List[T]) -> str: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import AcamlFixes, StreamProxies
from .Interfaces import DataChangeLevel

# Stubs for namespace: Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Utilities

class Constants:  # Class
    InjectionMetadataCustomField: str = ...  # static # readonly
    OriginalPackagingModeCustomField: str = ...  # static # readonly

class ProcessingTransaction:  # Class
    def __init__(self, docId: System.Guid) -> None: ...

    IsActive: bool  # readonly

    def Open(self) -> None: ...
    def TryOpen(self) -> bool: ...
    def Commit(self, dataChangeLevel: DataChangeLevel) -> None: ...
    def TryCommit(self, dataChangeLevel: DataChangeLevel) -> None: ...

class TempFileStream(System.IDisposable, System.IO.Stream):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, sourceStream: System.IO.Stream) -> None: ...

    CanRead: bool  # readonly
    CanSeek: bool  # readonly
    CanWrite: bool  # readonly
    Length: int  # readonly
    Position: int

    def Read(self, buffer: List[int], offset: int, count: int) -> int: ...
    def Write(self, buffer: List[int], offset: int, count: int) -> None: ...
    def Flush(self) -> None: ...
    def SetLength(self, value_: int) -> None: ...
    def Seek(self, offset: int, origin: System.IO.SeekOrigin) -> int: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .ScriptIf import (
    ICompliance,
    ILibraryAccess,
    IMainForm,
    IScriptEngine,
    IScriptInterface,
    IScriptProgress,
    IScriptScope,
    IUIState,
)
from .Utils import SpectrumKey

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.ScriptIfImpls

class Compliance(System.MarshalByRefObject, ICompliance):  # Class
    ConnectionTicket: str  # readonly
    IsActive: bool  # readonly
    IsLocal: bool  # readonly
    Name: str  # readonly
    User: str  # readonly

class LibraryAccess(
    System.MarshalByRefObject, System.IDisposable, ILibraryAccess
):  # Class
    CompoundCount: int  # readonly
    Format: Agilent.MassSpectrometry.DataAnalysis.MSLibraryFormat  # readonly

    def Base64ToDoubleArray(self, base64: str) -> List[float]: ...
    def ExportTOJCAMP(self, file: str, spectrumKeys: List[SpectrumKey]) -> None: ...
    def GetSpectrumIds(self, compoundId: int) -> List[int]: ...
    def GetCompoundProperty(self, compoundId: int, name: str) -> Any: ...
    def GetSpectrumProperty(
        self, compoundId: int, spectrumId: int, name: str
    ) -> Any: ...
    def GetCompoundId(self, index: int) -> int: ...
    def DoubleArrayToBase64(self, values: List[float]) -> str: ...
    def Dispose(self) -> None: ...

class ScriptEngine(
    IScriptEngine, System.MarshalByRefObject, System.IDisposable
):  # Class
    CurrentScope: IScriptScope  # readonly
    DebugMode: bool  # readonly
    Engine: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ScriptEngine.IScriptEngine
    )  # readonly
    Globals: IScriptScope  # readonly
    IsRunning: bool  # readonly

    def CreateScope(self) -> IScriptScope: ...
    @overload
    def Execute(
        self,
        reader: System.IO.TextReader,
        encoding: System.Text.Encoding,
        scope: IScriptScope,
    ) -> Any: ...
    @overload
    def Execute(
        self,
        stream: System.IO.Stream,
        encoding: System.Text.Encoding,
        scope: IScriptScope,
    ) -> Any: ...
    @staticmethod
    def SetDebugEngine(
        engine: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ScriptEngine.IronEngine,
        initEngine: System.Action[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.ScriptEngine.IronEngine,
            Any,
        ],
    ) -> None: ...
    def Dispose(self) -> None: ...
    def ExecuteFile(self, file: str, scope: IScriptScope) -> Any: ...

class ScriptInterface(
    IScriptInterface, System.MarshalByRefObject, System.IDisposable
):  # Class
    Compliance: ICompliance  # readonly
    LibraryAccess: ILibraryAccess  # readonly
    MainForm: IMainForm  # readonly
    ScriptEngine: IScriptEngine  # readonly
    ScriptProgress: IScriptProgress  # readonly
    UIState: IUIState  # readonly
    _ScriptInterface: IScriptInterface  # readonly

    def Dispose(self) -> None: ...
    def _GetPrivateProfileString(
        self, section: str, key: str, defaultValue: str, fileName: str
    ) -> str: ...
    def _WritePrivateProfileString(
        self, section: str, key: str, value_: str, fileName: str
    ) -> int: ...

class ScriptProgress(
    System.MarshalByRefObject, System.IDisposable, IScriptProgress
):  # Class
    CancellationPending: bool  # readonly
    IsVisible: bool  # readonly
    Marquee: bool
    Message: str
    ProgressMaximum: int
    ProgressStep: int
    ProgressValue: int

    def Dispose(self) -> None: ...
    def Cancel(self) -> None: ...

class UIState(System.MarshalByRefObject, IUIState, System.IDisposable):  # Class
    CanRedo: bool  # readonly
    CanUndo: bool  # readonly
    Format: Agilent.MassSpectrometry.DataAnalysis.MSLibraryFormat  # readonly
    HasLibrary: bool  # readonly
    IsCommandRunning: bool  # readonly
    IsDirty: bool  # readonly
    IsReadOnly: bool  # readonly
    LibraryAccess: ILibraryAccess  # readonly
    LibraryName: str  # readonly
    LibraryPath: str  # readonly
    MainForm: IMainForm  # readonly
    ScriptEngine: IScriptEngine  # readonly
    ScriptInterface: IScriptInterface  # readonly
    ScriptProgress: IScriptProgress  # readonly
    SelectedCompoundCount: int  # readonly
    SelectedCompounds: Iterable[int]  # readonly
    _ScriptInterface: (
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.ScriptIfImpls.ScriptInterface
    )  # readonly

    def SelectCompounds(self, compoundIds: Iterable[int]) -> None: ...
    def ClearCompoundSelection(self) -> None: ...
    @overload
    def Dispose(self) -> None: ...
    @overload
    def Dispose(self, disposing: bool) -> None: ...
    def ShowAboutBox(self) -> None: ...
    def GetTools(self, id: str) -> List[Any]: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import INumericCustomFormat
from .Compliance import ICompliance

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UILibrary

class EntryGrid(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.DataGridView,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def GetDefaultColumnNames() -> List[str]: ...

class ILibraryApp(Agilent.MassHunter.Quantitative.UIModel.ILibraryApp):  # Interface
    SelectedEntry: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UILibrary.ILibraryEntry
    )  # readonly
    Site: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UILibrary.ILibraryAppSite

    def ClearEntries(self) -> None: ...
    def ShowMessage(
        self,
        message: str,
        buttons: System.Windows.Forms.MessageBoxButtons,
        icon: System.Windows.Forms.MessageBoxIcon,
    ) -> System.Windows.Forms.DialogResult: ...
    def AddTool(self, name: str, caption: str, image: System.Drawing.Image) -> None: ...
    def ExitApplication(self) -> None: ...

class ILibraryAppSite(
    Agilent.MassHunter.Quantitative.UIModel.ILibraryAppSite
):  # Interface
    def OnToolClicked(self, name: str) -> None: ...
    def OnCloseWindow(self) -> None: ...

class ILibraryEntry(object):  # Interface
    BoilPt: float  # readonly
    CASNumber: str  # readonly
    CompoundName: str  # readonly
    Formula: str  # readonly
    Library: Agilent.MassSpectrometry.DataAnalysis.ILibrary  # readonly
    LibraryPath: str  # readonly
    LibraryRetentionIndex: float  # readonly
    LibraryRetentionTime: float  # readonly
    MatchFactor: float  # readonly
    MeltPt: float  # readonly
    MolecularWeight: float  # readonly
    OverlapCount: int  # readonly
    RetentionTimeDifference: float  # readonly
    Spectrum: Agilent.MassHunter.Quantitative.UIModel.ISpectrumTransfer  # readonly
    SpectrumId: Agilent.MassSpectrometry.DataAnalysis.ISpectrumId  # readonly
    TargetRetentionIndex: float  # readonly

class LibraryApp(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UILibrary.ILibraryApp,
    Agilent.MassHunter.Quantitative.UIModel.ILibraryApp,
    System.IDisposable,
):  # Class
    HasLibrary: bool  # readonly
    TargetSpectrum: (
        Agilent.MassHunter.Quantitative.UIModel.ISpectrumTransfer
    )  # readonly

    @staticmethod
    def CreateInstance(
        compliance: ICompliance,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.UILibrary.ILibraryApp: ...
    def SetLibraries(
        self,
        libraries: List[Agilent.MassHunter.Quantitative.UIModel.ILibraryItem],
        searchType: Agilent.MassSpectrometry.DataAnalysis.MultipleLibrarySearchType,
        libraryUnitMassFormat: INumericCustomFormat,
        libraryAccurateMassFormat: INumericCustomFormat,
    ) -> None: ...
    def ShowWindow(self) -> None: ...
    def Dispose(self) -> None: ...
    def Search(self) -> None: ...
    def SetTargetSpectrum(
        self,
        transfer: Agilent.MassHunter.Quantitative.UIModel.ISpectrumTransfer,
        massDisplayFormat: INumericCustomFormat,
    ) -> None: ...

class LibraryConfiguration:  # Class
    Section: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UILibrary.LibraryConfigurationSettingsSection
    )  # static # readonly

class LibraryConfigurationSettingsSection(
    System.Configuration.ConfigurationSection
):  # Class
    def __init__(self) -> None: ...

    BackColor: System.Drawing.Color
    ForeColor: System.Drawing.Color
    LibrarySpectrumColor: System.Drawing.Color
    MolecularStructureColor: System.Drawing.Color  # readonly
    SupportsCASLink: bool  # readonly
    TargetSpectrumColor: System.Drawing.Color

class LibraryException(
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
    System.Exception,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(self, message: str, innerException: System.Exception) -> None: ...

class LibraryItem(Agilent.MassHunter.Quantitative.UIModel.ILibraryItem):  # Struct
    def __init__(
        self,
        library: Agilent.MassSpectrometry.DataAnalysis.ILibrary,
        parameters: Agilent.MassSpectrometry.DataAnalysis.LibrarySearchParams,
    ) -> None: ...

    Library: Agilent.MassSpectrometry.DataAnalysis.ILibrary  # readonly
    Parameters: Agilent.MassSpectrometry.DataAnalysis.LibrarySearchParams  # readonly

class LibraryPrintDocument(
    System.IDisposable,
    System.ComponentModel.IComponent,
    System.Drawing.Printing.PrintDocument,
):  # Class
    def __init__(
        self,
        title: str,
        grid: System.Windows.Forms.DataGridView,
        plot: Agilent.MassSpectrometry.GUI.Plot.PlotControl,
    ) -> None: ...

class LibraryWindow(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self, compliance: ICompliance) -> None: ...

class SpectrumPlotControl(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.IBindableComponent,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    Agilent.MassSpectrometry.GUI.Plot.PlotControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    ShowMolecularStructure: bool

    def GetAutoScaleRangeX(
        self, pane: Agilent.MassSpectrometry.GUI.Plot.Pane
    ) -> Agilent.MassSpectrometry.GUI.Plot.PlotRange: ...
    def GetAutoScaleRangeY(
        self, pane: Agilent.MassSpectrometry.GUI.Plot.Pane, minX: float, maxX: float
    ) -> Agilent.MassSpectrometry.GUI.Plot.PlotRange: ...
    def GetPreferredYRangeLimit(
        self, row: int, column: int
    ) -> Agilent.MassSpectrometry.GUI.Plot.PlotRange: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
T = TypeVar("T")
from .Engine import IGraphicsCanvas, IReportContext, IReportRenderer, ITableRenderer
from .Template import IGraphics, IImage, IPage, ITextbox

# Stubs for namespace: Agilent.MassHunter.ReportBuilder.InfragisticsRenderer

class BrushKey:  # Class
    def GetHashCode(self) -> int: ...
    def Equals(self, obj: Any) -> bool: ...

class Canvas(
    Agilent.MassSpectrometry.GUI.Plot.IGraphics, IGraphicsCanvas, System.IDisposable
):  # Class
    Clip: System.Drawing.Region
    Graphics: System.Drawing.Graphics  # readonly
    HasGraphics: bool  # readonly
    IgnoreFontName: bool

    @overload
    def FillRectangle(
        self,
        brush: System.Drawing.Brush,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...
    @overload
    def FillRectangle(
        self, brush: System.Drawing.Brush, rect: System.Drawing.RectangleF
    ) -> None: ...
    def DrawImage(
        self,
        image: System.Drawing.Image,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...
    def DrawRectangle(
        self, pen: System.Drawing.Pen, x1: float, y1: float, x2: float, y2: float
    ) -> None: ...
    def SaveState(self) -> None: ...
    def DrawLines(
        self, pen: System.Drawing.Pen, points: List[System.Drawing.PointF]
    ) -> None: ...
    def DrawEllipse(
        self, pen: System.Drawing.Pen, x: float, y: float, width: float, height: float
    ) -> None: ...
    def GetGraphics(self) -> T: ...
    def RestoreState(self) -> None: ...
    def FillEllipse(
        self,
        brush: System.Drawing.Brush,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...
    @overload
    def DrawLine(
        self,
        pen: System.Drawing.Pen,
        p1: System.Drawing.PointF,
        p2: System.Drawing.PointF,
    ) -> None: ...
    @overload
    def DrawLine(
        self, pen: System.Drawing.Pen, x1: float, y1: float, x2: float, y2: float
    ) -> None: ...
    def DrawPolygon(
        self, pen: System.Drawing.Pen, points: List[System.Drawing.PointF]
    ) -> None: ...
    @overload
    def DrawString(
        self,
        text: str,
        font: System.Drawing.Font,
        br: System.Drawing.Brush,
        x: float,
        y: float,
        format: System.Drawing.StringFormat,
    ) -> None: ...
    @overload
    def DrawString(
        self,
        text: str,
        font: System.Drawing.Font,
        br: System.Drawing.Brush,
        rect: System.Drawing.RectangleF,
        format: System.Drawing.StringFormat,
    ) -> None: ...
    def DrawXps(self, stream: System.IO.Stream) -> None: ...
    def FillPolygon(
        self, brush: System.Drawing.Brush, points: List[System.Drawing.PointF]
    ) -> None: ...
    def ConvertBounds(
        self, bounds: System.Drawing.RectangleF
    ) -> System.Drawing.RectangleF: ...
    def DrawBitmap(
        self,
        bitmap: System.Drawing.Bitmap,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...
    def DrawBeziers(
        self, pen: System.Drawing.Pen, points: List[System.Drawing.PointF]
    ) -> None: ...
    def Dispose(self) -> None: ...
    def MultiplyTransform(
        self,
        matrix: System.Drawing.Drawing2D.Matrix,
        order: System.Drawing.Drawing2D.MatrixOrder,
    ) -> None: ...
    @overload
    def MeasureString(
        self, text: str, font: System.Drawing.Font, width: int
    ) -> System.Drawing.SizeF: ...
    @overload
    def MeasureString(
        self, text: str, font: System.Drawing.Font
    ) -> System.Drawing.SizeF: ...

class Renderer(IReportRenderer, System.IDisposable):  # Class
    def __init__(
        self,
        stream: System.IO.Stream,
        format: Infragistics.Documents.Reports.Report.FileFormat,
    ) -> None: ...

    Context: IReportContext

    def RenderImage(self, image: IImage) -> None: ...
    def StartDocument(self) -> None: ...
    def PageBreak(self) -> None: ...
    def RenderTable(self, numColumns: int) -> ITableRenderer: ...
    def RenderGraphics(self, graphics: IGraphics) -> None: ...
    def RenderText(self, textbox: ITextbox) -> None: ...
    def EndDocument(self) -> None: ...
    def SetPage(self, page: IPage) -> None: ...
    def Dispose(self) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassHunter.Quantitative.QuantWPF.Tools

class CagToolManager(
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolManager.IToolManager,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolManager,
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolbarsManager,
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolManager.ToolManagerBase,
):  # Class
    def __init__(
        self,
        ribbon: Infragistics.Windows.Ribbon.XamRibbon,
        uiState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IUIState,
    ) -> None: ...
    def RegisterScriptToolHandler(
        self, id: str, module: str, setState: str, execute: str
    ) -> None: ...
    def SetToolState(
        self, state: Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.IToolState
    ) -> None: ...
    def GetImage(self, image: str) -> System.Windows.Media.Imaging.BitmapSource: ...
    def RegisterScriptCategoryHandler(
        self, category: str, module: str, setState: str, execute: str
    ) -> None: ...
    @overload
    def GetToolCaption(self, id: str) -> str: ...
    @overload
    def GetToolCaption(
        self, id: str, culture: System.Globalization.CultureInfo
    ) -> str: ...

class CiwToolManager(
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolManager.IToolManager,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolManager,
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolbarsManager,
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolManager.ToolManagerBase,
):  # Class
    def __init__(
        self,
        ribbon: Infragistics.Windows.Ribbon.XamRibbon,
        uiState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IUIState,
    ) -> None: ...
    @overload
    def GetToolCaption(self, id: str) -> str: ...
    @overload
    def GetToolCaption(
        self, id: str, culture: System.Globalization.CultureInfo
    ) -> str: ...
    def RegisterScriptCategoryHandler(
        self, category: str, module: str, setState: str, execute: str
    ) -> None: ...
    def RegisterScriptToolHandler(
        self, tool: str, module: str, setState: str, execute: str
    ) -> None: ...
    def GetImage(self, image: str) -> System.Windows.Media.Imaging.BitmapSource: ...

class ToolsUtil:  # Class
    @staticmethod
    def CheckWpfTools() -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.View

class CustomizeRibbonView(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IComponentConnector,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.IInputElement,
    System.Windows.Markup.IStyleConnector,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import UIContext

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Query

class LinqQuery(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Query.QueryBase,
):  # Class
    def __init__(self, uiContext: UIContext, queryFile: str) -> None: ...
    def GetColumnFormat(
        self, column: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.INumericCustomFormat: ...
    def GetColumnLabel(self, column: str) -> str: ...
    def RunQuery(self) -> Any: ...

class LinqQueryBase(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Query.QueryBase,
):  # Class
    ColumnFormats: List[
        System.Collections.Generic.KeyValuePair[
            str, Agilent.MassSpectrometry.DataAnalysis.Quantitative.INumericCustomFormat
        ]
    ]  # readonly
    ColumnLabels: List[System.Collections.Generic.KeyValuePair[str, str]]  # readonly

    def RunQuery(self) -> Any: ...

class LinqQueryCompilerOption:  # Class
    def __init__(self) -> None: ...

    Name: str
    Value: str

class LinqQueryOptions:  # Class
    def __init__(self) -> None: ...

    CompilerOptions: List[
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Query.LinqQueryCompilerOption
    ]
    Imports: List[str]
    Language: str
    Name: str
    References: List[str]

class QueryBase(System.IDisposable):  # Class
    def Dispose(self) -> None: ...
    def RunQuery(self) -> Any: ...

class QueryForm(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self, uiContext: UIContext) -> None: ...
    def Clear(self) -> None: ...
    def RunQuery(self, queryFile: str) -> None: ...

class SqlQuery(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Query.QueryBase,
):  # Class
    def __init__(self, uiContext: UIContext, queryFile: str) -> None: ...
    def RunQuery(self) -> Any: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import MolecularStructure

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure

class BottomHalfDiamond(
    Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanShape
):  # Class
    def __init__(self) -> None: ...
    def Draw(
        self,
        g: System.Drawing.Graphics,
        c: System.Drawing.Color,
        pen: System.Drawing.Pen,
        label: str,
        rect: System.Drawing.Rectangle,
        rotation: int,
    ) -> None: ...
    def NeedsRotation(self) -> bool: ...

class Circle(
    Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanShape
):  # Class
    def __init__(self) -> None: ...
    def Draw(
        self,
        g: System.Drawing.Graphics,
        c: System.Drawing.Color,
        pen: System.Drawing.Pen,
        label: str,
        rect: System.Drawing.Rectangle,
        rotation: int,
    ) -> None: ...
    def NeedsRotation(self) -> bool: ...

class DiagonalSquare(
    Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanShape
):  # Class
    def __init__(self) -> None: ...
    def Draw(
        self,
        g: System.Drawing.Graphics,
        c: System.Drawing.Color,
        pen: System.Drawing.Pen,
        label: str,
        rect: System.Drawing.Rectangle,
        rotation: int,
    ) -> None: ...
    def NeedsRotation(self) -> bool: ...

class Diamond(
    Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanShape
):  # Class
    def __init__(self) -> None: ...
    def Draw(
        self,
        g: System.Drawing.Graphics,
        c: System.Drawing.Color,
        pen: System.Drawing.Pen,
        label: str,
        rect: System.Drawing.Rectangle,
        rotation: int,
    ) -> None: ...
    def NeedsRotation(self) -> bool: ...

class GlycanGlycoCTParser(
    Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanParser
):  # Class
    def __init__(self) -> None: ...
    def ParseStructureSpec(
        self, structureSpec: str
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanTree
    ): ...

class GlycanKeggParser(
    Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanParser
):  # Class
    def __init__(self) -> None: ...
    def ParseStructureSpec(
        self, structureSpec: str
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanTree
    ): ...

class GlycanLinucsParser(
    Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanParser
):  # Class
    def __init__(self) -> None: ...
    def ParseStructureSpec(
        self, structureSpec: str
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanTree
    ): ...

class GlycanShape(object):  # Interface
    def Draw(
        self,
        g: System.Drawing.Graphics,
        c: System.Drawing.Color,
        pen: System.Drawing.Pen,
        label: str,
        rect: System.Drawing.Rectangle,
        rotation: int,
    ) -> None: ...
    def NeedsRotation(self) -> bool: ...

class GlycanStructure(
    Agilent.MassSpectrometry.DataAnalysis.IMolecularStructure, MolecularStructure
):  # Class
    def __init__(self) -> None: ...

    pen: System.Drawing.Pen  # static

    Direction: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanStructure.DrawingOrientation
    )
    GlycanStructureContextMenu: System.Windows.Forms.ContextMenu  # readonly
    ShowLinkage: bool
    StructureSpec: str
    UseSymbols: bool

    def ReadStructureSpecFromFile(self, filename: str) -> None: ...
    def ReadStructureSpecFromStream(self, sr: System.IO.TextReader) -> None: ...
    def PaintStructure(
        self, g: System.Drawing.Graphics, ctrl: System.Windows.Forms.Control
    ) -> None: ...

    # Nested Types

    class DrawingOrientation(
        System.IConvertible, System.IComparable, System.IFormattable
    ):  # Struct
        BottomToTop: (
            Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanStructure.DrawingOrientation
        ) = ...  # static # readonly
        LeftToRight: (
            Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanStructure.DrawingOrientation
        ) = ...  # static # readonly
        RightToLeft: (
            Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanStructure.DrawingOrientation
        ) = ...  # static # readonly
        TopToBottom: (
            Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanStructure.DrawingOrientation
        ) = ...  # static # readonly

class GlycanSymbol:  # Class
    def __init__(
        self,
        shape: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanShape,
        color: System.Drawing.Color,
        pen: System.Drawing.Pen,
    ) -> None: ...

    Color: System.Drawing.Color
    Label: str
    Pen: System.Drawing.Pen
    Shape: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanShape
    )

    def Draw(
        self, g: System.Drawing.Graphics, rect: System.Drawing.Rectangle, rotation: int
    ) -> None: ...

class GlycanTree:  # Class
    def __init__(self) -> None: ...

    AmbiguousNode: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanTree.GlycanNode
    )
    Edges: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanTree.GlycanEdge
    ]
    GlycanId: str
    HeadNode: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanTree.GlycanNode
    )
    Nodes: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanTree.GlycanNode
    ]
    ParseError: bool

    # Nested Types

    class GlycanEdge:  # Class
        def __init__(self) -> None: ...

        ChildLinkage: str
        ChildNode: (
            Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanTree.GlycanNode
        )
        ParentLinkage: str
        ParentNode: (
            Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanTree.GlycanNode
        )

    class GlycanNode:  # Class
        def __init__(self) -> None: ...

        BottomLabel: str
        Bounds: System.Drawing.Rectangle
        Children: System.Collections.Generic.List[
            Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanTree.GlycanNode
        ]
        Id: str
        Name: str
        ParentEdge: (
            Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanTree.GlycanEdge
        )
        Parents: System.Collections.Generic.List[
            Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanTree.GlycanNode
        ]
        RightAngleOnly: bool
        SortKey: str
        Symbol: (
            Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanSymbol
        )
        TopLabel: str

        def InsertNodeBefore(
            self,
            child: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanTree.GlycanNode,
            tree: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanTree,
        ) -> None: ...
        def InsertNodeAfter(
            self,
            parent: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanTree.GlycanNode,
            tree: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanTree,
            linkage: str,
        ) -> None: ...
        def RemoveNode(
            self,
            tree: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanTree,
        ) -> None: ...
        def RemoveLinkage(self, str: str, showLinkage: bool) -> str: ...

class GlycanUtils:  # Class
    def __init__(self) -> None: ...

    pen: System.Drawing.Pen  # static

    @staticmethod
    def stripName(s: str) -> str: ...

class LeftBracket(
    Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanShape
):  # Class
    def __init__(self) -> None: ...
    def Draw(
        self,
        g: System.Drawing.Graphics,
        c: System.Drawing.Color,
        pen: System.Drawing.Pen,
        label: str,
        rect: System.Drawing.Rectangle,
        rotation: int,
    ) -> None: ...
    def NeedsRotation(self) -> bool: ...

class LeftCurlyBracket(
    Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanShape
):  # Class
    def __init__(self) -> None: ...
    def Draw(
        self,
        g: System.Drawing.Graphics,
        c: System.Drawing.Color,
        pen: System.Drawing.Pen,
        label: str,
        rect: System.Drawing.Rectangle,
        rotation: int,
    ) -> None: ...
    def NeedsRotation(self) -> bool: ...

class LeftHalfDiamond(
    Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanShape
):  # Class
    def __init__(self) -> None: ...
    def Draw(
        self,
        g: System.Drawing.Graphics,
        c: System.Drawing.Color,
        pen: System.Drawing.Pen,
        label: str,
        rect: System.Drawing.Rectangle,
        rotation: int,
    ) -> None: ...
    def NeedsRotation(self) -> bool: ...

class Pentangle(
    Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanShape
):  # Class
    def __init__(self) -> None: ...
    def Draw(
        self,
        g: System.Drawing.Graphics,
        c: System.Drawing.Color,
        pen: System.Drawing.Pen,
        label: str,
        rect: System.Drawing.Rectangle,
        rotation: int,
    ) -> None: ...
    def NeedsRotation(self) -> bool: ...

class RightBracket(
    Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanShape
):  # Class
    def __init__(self) -> None: ...
    def Draw(
        self,
        g: System.Drawing.Graphics,
        c: System.Drawing.Color,
        pen: System.Drawing.Pen,
        label: str,
        rect: System.Drawing.Rectangle,
        rotation: int,
    ) -> None: ...
    def NeedsRotation(self) -> bool: ...

class RightHalfDiamond(
    Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanShape
):  # Class
    def __init__(self) -> None: ...
    def Draw(
        self,
        g: System.Drawing.Graphics,
        c: System.Drawing.Color,
        pen: System.Drawing.Pen,
        label: str,
        rect: System.Drawing.Rectangle,
        rotation: int,
    ) -> None: ...
    def NeedsRotation(self) -> bool: ...

class RotatedTriangle(
    Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanShape
):  # Class
    def __init__(self) -> None: ...
    def Draw(
        self,
        g: System.Drawing.Graphics,
        c: System.Drawing.Color,
        pen: System.Drawing.Pen,
        label: str,
        rect: System.Drawing.Rectangle,
        rotation: int,
    ) -> None: ...
    def NeedsRotation(self) -> bool: ...

class Square(
    Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanShape
):  # Class
    def __init__(self) -> None: ...
    def Draw(
        self,
        g: System.Drawing.Graphics,
        c: System.Drawing.Color,
        pen: System.Drawing.Pen,
        label: str,
        rect: System.Drawing.Rectangle,
        rotation: int,
    ) -> None: ...
    def NeedsRotation(self) -> bool: ...

class Squiggle(
    Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanShape
):  # Class
    def __init__(self) -> None: ...
    def Draw(
        self,
        g: System.Drawing.Graphics,
        c: System.Drawing.Color,
        pen: System.Drawing.Pen,
        label: str,
        rect: System.Drawing.Rectangle,
        rotation: int,
    ) -> None: ...
    def NeedsRotation(self) -> bool: ...

class SquiggleCircle(
    Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanShape
):  # Class
    def __init__(self) -> None: ...
    def Draw(
        self,
        g: System.Drawing.Graphics,
        c: System.Drawing.Color,
        pen: System.Drawing.Pen,
        label: str,
        rect: System.Drawing.Rectangle,
        rotation: int,
    ) -> None: ...
    def NeedsRotation(self) -> bool: ...

class Star(
    Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanShape
):  # Class
    def __init__(self) -> None: ...
    def Draw(
        self,
        g: System.Drawing.Graphics,
        c: System.Drawing.Color,
        pen: System.Drawing.Pen,
        label: str,
        rect: System.Drawing.Rectangle,
        rotation: int,
    ) -> None: ...
    def NeedsRotation(self) -> bool: ...

class TopHalfDiamond(
    Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanShape
):  # Class
    def __init__(self) -> None: ...
    def Draw(
        self,
        g: System.Drawing.Graphics,
        c: System.Drawing.Color,
        pen: System.Drawing.Pen,
        label: str,
        rect: System.Drawing.Rectangle,
        rotation: int,
    ) -> None: ...
    def NeedsRotation(self) -> bool: ...

class Triangle(
    Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.GlycanStructure.GlycanShape
):  # Class
    def __init__(self) -> None: ...
    def Draw(
        self,
        g: System.Drawing.Graphics,
        c: System.Drawing.Color,
        pen: System.Drawing.Pen,
        label: str,
        rect: System.Drawing.Rectangle,
        rotation: int,
    ) -> None: ...
    def NeedsRotation(self) -> bool: ...
